@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi.
 
-    Copyright (c) 2006 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2006 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-    USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "agentwidget.h"
@@ -55,11 +42,11 @@ public:
     explicit TextDialog(QWidget *parent = nullptr)
         : QDialog(parent)
     {
-        QVBoxLayout *mainLayout = new QVBoxLayout(this);
+        auto *mainLayout = new QVBoxLayout(this);
         mText = new QPlainTextEdit(this);
         mText->setReadOnly(true);
 
-        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok, this);
+        auto *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok, this);
         QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
         okButton->setDefault(true);
         okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -137,15 +124,20 @@ AgentWidget::AgentWidget(QWidget *parent)
     connect(ui.restartButton, &QPushButton::clicked, this, &AgentWidget::restartAgent);
 
     ui.instanceWidget->agentFilterProxyModel()->setFilterCaseSensitivity(Qt::CaseInsensitive);
-    connect(ui.mFilterAccount, &QLineEdit::textChanged, ui.instanceWidget->agentFilterProxyModel(), &AgentFilterProxyModel::setFilterFixedString);
+    connect(ui.mFilterAccount, &QLineEdit::textChanged, this, &AgentWidget::slotSearchAgentType);
     ui.mFilterAccount->installEventFilter(this);
     ControlGui::widgetNeedsAkonadi(this);
 }
 
+void AgentWidget::slotSearchAgentType(const QString &str)
+{
+    ui.instanceWidget->agentFilterProxyModel()->setFilterRegularExpression(str);
+}
+
 bool AgentWidget::eventFilter(QObject *obj, QEvent *event)
 {
     if (event->type() == QEvent::KeyPress && obj == ui.mFilterAccount) {
-        QKeyEvent *key = static_cast<QKeyEvent *>(event);
+        auto *key = static_cast<QKeyEvent *>(event);
         if ((key->key() == Qt::Key_Enter) || (key->key() == Qt::Key_Return)) {
             event->accept();
             return true;
@@ -161,7 +153,7 @@ void AgentWidget::addAgent()
         const AgentType agentType = dlg->agentType();
 
         if (agentType.isValid()) {
-            AgentInstanceCreateJob *job = new AgentInstanceCreateJob(agentType, this);
+            auto *job = new AgentInstanceCreateJob(agentType, this);
             job->configure(this);
             job->start(); // TODO: check result
         }
@@ -211,7 +203,7 @@ void AgentWidget::removeAgent()
                                        KStandardGuiItem::cancel(),
                                        QString(),
                                        KMessageBox::Dangerous)
-                == KMessageBox::Yes) {
+            == KMessageBox::Yes) {
             for (const AgentInstance &agent : list) {
                 AgentManager::self()->removeInstance(agent);
             }
@@ -243,10 +235,11 @@ void AgentWidget::configureAgentRemote()
 void AgentWidget::synchronizeAgent()
 {
     const AgentInstance::List list = ui.instanceWidget->selectedAgentInstances();
-    if (!list.isEmpty())
+    if (!list.isEmpty()) {
         for (AgentInstance agent : list) {
             agent.synchronize();
         }
+    }
 }
 
 void AgentWidget::toggleOnline()
@@ -340,7 +333,7 @@ void AgentWidget::slotCloneAgent()
     }
     const AgentType agentType = mCloneSource.type();
     if (agentType.isValid()) {
-        AgentInstanceCreateJob *job = new AgentInstanceCreateJob(agentType, this);
+        auto *job = new AgentInstanceCreateJob(agentType, this);
         connect(job, &KJob::result, this, &AgentWidget::cloneAgent);
         job->start();
     } else {
@@ -419,17 +412,21 @@ void AgentWidget::currentChanged()
         QString onlineStatus = (instance.isOnline() ? QStringLiteral("Online") : QStringLiteral("Offline"));
         QString agentStatus;
         switch (instance.status()) {
-        case AgentInstance::Idle: agentStatus =
-                i18nc("agent is in an idle state", "Idle");
+        case AgentInstance::Idle:
+            agentStatus
+                = i18nc("agent is in an idle state", "Idle");
             break;
-        case AgentInstance::Running: agentStatus =
-                i18nc("agent is running", "Running (%1%)", instance.progress());
+        case AgentInstance::Running:
+            agentStatus
+                = i18nc("agent is running", "Running (%1%)", instance.progress());
             break;
-        case AgentInstance::Broken: agentStatus =
-                i18nc("agent is broken somehow", "Broken");
+        case AgentInstance::Broken:
+            agentStatus
+                = i18nc("agent is broken somehow", "Broken");
             break;
-        case AgentInstance::NotConfigured: agentStatus =
-                i18nc("agent is not yet configured", "Not Configured");
+        case AgentInstance::NotConfigured:
+            agentStatus
+                = i18nc("agent is not yet configured", "Not Configured");
             break;
         }
         ui.statusLabel->setText(
@@ -468,4 +465,3 @@ void AgentWidget::resizeEvent(QResizeEvent *event)
 {
     ui.detailsBox->setVisible(event->size().height() > 400);
 }
-
