@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi.
 
-    Copyright (c) 2006 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2006 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-    USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "debugwidget.h"
@@ -41,7 +28,7 @@ using org::freedesktop::Akonadi::DebugInterface;
 DebugWidget::DebugWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
 
     QString service = QStringLiteral("org.freedesktop.Akonadi");
     if (Akonadi::ServerManager::hasInstanceIdentifier()) {
@@ -53,7 +40,7 @@ DebugWidget::DebugWidget(QWidget *parent)
     connect(cb, &QCheckBox::toggled, this, &DebugWidget::enableDebugger);
     layout->addWidget(cb);
 
-    QSplitter *splitter = new QSplitter(Qt::Vertical, this);
+    auto *splitter = new QSplitter(Qt::Vertical, this);
     splitter->setObjectName(QStringLiteral("debugSplitter"));
     layout->addWidget(splitter);
 
@@ -63,14 +50,13 @@ DebugWidget::DebugWidget(QWidget *parent)
     mGeneralView = new KTextEdit(splitter);
     mGeneralView->setReadOnly(true);
 
-
     org::freedesktop::Akonadi::TracerNotification *iface = new org::freedesktop::Akonadi::TracerNotification(QString(), QStringLiteral("/tracing/notifications"), QDBusConnection::sessionBus(), this);
 
     connect(iface, &org::freedesktop::Akonadi::TracerNotification::signalEmitted, this, &DebugWidget::signalEmitted);
     connect(iface, &org::freedesktop::Akonadi::TracerNotification::warningEmitted, this, &DebugWidget::warningEmitted);
     connect(iface, &org::freedesktop::Akonadi::TracerNotification::errorEmitted, this, &DebugWidget::errorEmitted);
 
-    QHBoxLayout *buttonLayout = new QHBoxLayout;
+    auto *buttonLayout = new QHBoxLayout;
     layout->addLayout(buttonLayout);
 
     QPushButton *clearGeneralButton = new QPushButton(QStringLiteral("Clear Information View"), this);
