@@ -1,23 +1,10 @@
 /*
  This file is part of Akonadi.
 
- Copyright (c) 2009 KDAB
- Author: Till Adam <adam@kde.org>
+ SPDX-FileCopyrightText: 2009 KDAB
+ SPDX-FileContributor: Till Adam <adam@kde.org>
 
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
- USA.
+ SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "jobtracker.h"
@@ -26,8 +13,6 @@
 #include "akonadiconsole_debug.h"
 #include <QString>
 #include <QStringList>
-#include <QPair>
-#include <QList>
 
 #include <cassert>
 
@@ -51,7 +36,10 @@ class JobTracker::Private
 {
 public:
     Private(JobTracker *_q)
-        : lastId(42), timer(_q), disabled(false), q(_q)
+        : lastId(42)
+        , timer(_q)
+        , disabled(false)
+        , q(_q)
     {
         timer.setSingleShot(true);
         timer.setInterval(200);
@@ -83,13 +71,14 @@ private:
 };
 
 JobTracker::JobTracker(const char *name, QObject *parent)
-    : QObject(parent), d(new Private(this))
+    : QObject(parent)
+    , d(new Private(this))
 {
     new JobTrackerAdaptor(this);
     const QString suffix = Akonadi::Instance::identifier().isEmpty() ? QString() : QLatin1Char('-') + Akonadi::Instance::identifier();
     QDBusConnection::sessionBus().registerService(QStringLiteral("org.kde.akonadiconsole") + suffix);
     QDBusConnection::sessionBus().registerObject(QLatin1Char('/') + QLatin1String(name),
-            this, QDBusConnection::ExportAdaptors);
+                                                 this, QDBusConnection::ExportAdaptors);
 }
 
 JobTracker::~JobTracker()
