@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2018 Daniel Vrátil <dvratil@kde.org>
+    SPDX-FileCopyrightText: 2018 Daniel Vrátil <dvratil@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "logging.h"
@@ -54,8 +41,8 @@ Logging::Logging(QWidget *parent)
     mEnabledCheckbox = new QCheckBox(QStringLiteral("Enable"));
     connect(mEnabledCheckbox, &QCheckBox::toggled,
             this, [this](bool toggled) {
-                Q_EMIT enabledChanged(toggled);
-            });
+        Q_EMIT enabledChanged(toggled);
+    });
     l->addWidget(mEnabledCheckbox);
 
     auto h = new QHBoxLayout;
@@ -92,8 +79,8 @@ Logging::Logging(QWidget *parent)
     mView->setRootIsDecorated(false);
     l->addWidget(mView);
     mView->setModel(filterModel);
-    mModel->setAppFilterModel(qobject_cast<QStandardItemModel*>(mAppFilter->model()));
-    mModel->setCategoryFilterModel(qobject_cast<QStandardItemModel*>(mCategoryFilter->model()));
+    mModel->setAppFilterModel(qobject_cast<QStandardItemModel *>(mAppFilter->model()));
+    mModel->setCategoryFilterModel(qobject_cast<QStandardItemModel *>(mCategoryFilter->model()));
 
     h = new QHBoxLayout;
     l->addLayout(h);
@@ -116,15 +103,12 @@ Logging::~Logging()
     config.writeEntry("view", mView->header()->saveState());
 }
 
-
 bool Logging::enabled() const
 {
     return mEnabledCheckbox->isChecked();
 }
 
-void Logging::message(qint64 timestamp, const QString &app, qint64 pid, int type, const QString &category,
-                      const QString &file, const QString &function, int line,
-                      int /*version*/, const QString &msg)
+void Logging::message(qint64 timestamp, const QString &app, qint64 pid, int type, const QString &category, const QString &file, const QString &function, int line, int /*version*/, const QString &msg)
 {
     mModel->addMessage(timestamp, app, pid, static_cast<QtMsgType>(type), category, file, function, line, msg);
 }
@@ -151,7 +135,7 @@ void Logging::saveToFile()
             stream << msg.category << " ";
         }
         if (!msg.function.isEmpty()) {
-               stream << msg.function << ": ";
+            stream << msg.function << ": ";
         }
         stream << msg.message << "\n";
     }
