@@ -1,35 +1,21 @@
 /*
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #include "monitorsmodel.h"
 #include "akonadiconsole_debug.h"
 #include <AkonadiCore/Monitor>
-#include <AkonadiCore/NotificationSubscriber>
 #include <AkonadiCore/Session>
 
 #include <QTimer>
 
 Q_DECLARE_METATYPE(Akonadi::NotificationSubscriber)
 
-MonitorsModel::MonitorsModel(QObject *parent):
-    QAbstractItemModel(parent),
-    mMonitor(nullptr)
+MonitorsModel::MonitorsModel(QObject *parent)
+    : QAbstractItemModel(parent)
 {
     QTimer::singleShot(0, this, &MonitorsModel::init);
 }
@@ -137,7 +123,7 @@ QVariant MonitorsModel::data(const QModelIndex &index, int role) const
         if (index.row() >= subscribers.count()) {
             return {};
         }
-        const auto subscriber = subscribers.at(index.row()); 
+        const auto subscriber = subscribers.at(index.row());
         if (role == Qt::DisplayRole || role == Qt::ToolTipRole) {
             return subscriber.subscriber();
         } else if (role == SubscriberRole) {
@@ -187,4 +173,3 @@ QModelIndex MonitorsModel::index(int row, int column, const QModelIndex &parent)
 
     return createIndex(row, column, parent.row());
 }
-
