@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 2014  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2014 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  */
 
@@ -60,7 +48,7 @@ private:
     QStandardItemModel *mAttributesModel = nullptr;
     QStandardItemModel *mRemoteIdsModel = nullptr;
 
-    bool mChanged;
+    bool mChanged = false;
     QSet<QString> mChangedAttrs;
     QSet<QString> mRemovedAttrs;
     QSet<QString> mChangedRIDs;
